#
# Example script capturing Cosmographia's remdering of the scene 
# observed by ISS NAC. Desired FOV size is set by setFOV 
# function.
#

#
# Import cosmoscripting.
#
import cosmoscripting
cosmo = cosmoscripting.Cosmo()

dir = "/Users/bsemenov/cosmographia/CASSINI/"

cosmo.setTime( "2005-09-22 19:22:17.318 UTC" )

#
# Load catalogs.
#
cosmo.loadCatalogFile(dir+"spice_CASSINI.json")
cosmo.loadCatalogFile(dir+"spacecraft_CASSINI.json")
cosmo.loadCatalogFile(dir+"sensors/sensor_CASSINI_ISS_NAC-SATURN.json").wait(3)

#
# Pause time.
#
cosmo.pause()

#
# Set program's FOV size to 0.4 degrees, slightly larger than NAC's
# 0.35 degree FOV. Make the program take 3 seconds to zoom in from 
# the default FOV to the new setting.
#
cosmo.setFov(0.4,3)

#
# Set observer location to 10 meters on the instrument frame 
# Z axis (assumed to be boresight), looking along Z axis, with
# with the vertical directon aligned with instrument frame Y axis. 
#
cosmo.moveToPov("CAS_ISS_NAC",[0,0,0.01],[0,0,1],[0,1,0],1).wait(2)

#
# Set times and apture image.
#
cosmo.setTime( "2009-10-19 09:09:54.606 UTC" )

cosmo.loadCatalogFile(dir+"saturn-sats-actual-spice.json")
cosmo.saveScreenShotToFile(dir+"cosmo_cas_iss_nac_20091019090954_actual.png").wait(1)
cosmo.unloadLastCatalog()

cosmo.loadCatalogFile(dir+"saturn-sats-tiny-spice.json")
cosmo.saveScreenShotToFile(dir+"cosmo_cas_iss_nac_20091019090954_tiny.png").wait(1)
cosmo.unloadLastCatalog()

cosmo.setTime( "2005-12-23 23:52:41.851 UTC" )

cosmo.loadCatalogFile(dir+"saturn-sats-actual-spice.json")
cosmo.saveScreenShotToFile(dir+"cosmo_cas_iss_nac_20051223235241_actual.png").wait(1)
cosmo.unloadLastCatalog()

cosmo.loadCatalogFile(dir+"saturn-sats-tiny-spice.json")
cosmo.saveScreenShotToFile(dir+"cosmo_cas_iss_nac_20051223235241_tiny.png").wait(1)
cosmo.unloadLastCatalog()

cosmo.setTime( "2005-09-22 19:22:17.318 UTC" )

cosmo.loadCatalogFile(dir+"saturn-sats-actual-spice.json")
cosmo.saveScreenShotToFile(dir+"cosmo_cas_iss_nac_20050922192217_actual.png").wait(1)
cosmo.unloadLastCatalog()

cosmo.loadCatalogFile(dir+"saturn-sats-tiny-spice.json")
cosmo.saveScreenShotToFile(dir+"cosmo_cas_iss_nac_20050922192217_tiny.png").wait(1)
cosmo.unloadLastCatalog()

#
# Exit.
#
#cosmo.quit()
